@@ -1,6 +1,6 @@
-#!/usr/bin/perl
+#!/usr/local/bin/perl
 # ------------------------------------------------------------------------------
-#  Copyright 2003-2006 Alex Peeters [alex.peeters@citap.be]
+#  Copyright 2003-2007 Alex Peeters [alex.peeters@citap.be]
 # ------------------------------------------------------------------------------
 # rsync-wrapper for asnmtap, v2.002.xxx - wrapper script for rsync
 #   execution via ssh key for use with rsync-mirror & rsync-mirror.conf
@@ -34,6 +34,9 @@ my $denyString = 'Access Denied! Sorry';
 # The real path of rsync.
 my $rsyncPath = '/usr/bin/rsync';
 
+# 1 = rsync version 2.6.7 or higher or 0 = otherwise
+my $rsync_version_2_6_7_or_higher = 1;
+
 # 1 = 'capture_exec("$system_action")' or 0 = 'system ("$system_action")'
 my $captureOutput = 1;
 
@@ -89,7 +92,7 @@ print SSHOUT ("ARG3 = $rsync_argv[3]\n") if ($debug);
 print SSHOUT ("ARG4 = $rsync_argv[4]\n") if ($debug);
 print SSHOUT ("ARG5 = $rsync_argv[5]\n") if ($debug && $rsync_argv[2] eq '--sender');
 
-# ARG[0] Complain if the command is not "rsync".
+# ARG[0] Complain if the command is not 'rsync'.
 unless ($rsync_argv[0] eq 'rsync') {
   print SSHOUT ("ssh authorized_key account restricted: only rsync allowed\n");
   $ok = $FALSE;
@@ -97,7 +100,7 @@ unless ($rsync_argv[0] eq 'rsync') {
 
 # ARG[1] Complain if this arg is not --server
 unless ($rsync_argv[1] eq '--server') {
-  print SSHOUT ("ARG[1] <$rsync_argv[1]> Failure\n");
+  print SSHOUT ("ARG[1] <$rsync_argv[1]> Failure: this arg is not --server\n");
   $ok = $FALSE;
 }
 
@@ -115,14 +118,14 @@ my $teller = 0;
 foreach $option (@options) { if ($rsync_argv[$argPos] eq $option) { $teller++; } }
 
 unless ( $teller != 0 )  {
-  print SSHOUT ("ARG[$argPos] <$rsync_argv[$argPos]> Failure\n");
+  print SSHOUT ("ARG[$argPos] <$rsync_argv[$argPos]> Failure: this arg is not in \@options\n");
   $ok = $FALSE;
 }
 
 # ARG[$argPos] Complain if this arg is not .
 $argPos++;
 unless ($rsync_argv[$argPos] eq '.') {
-  print SSHOUT ("ARG[$argPos] <$rsync_argv[$argPos]> Failure\n");
+  print SSHOUT ("ARG[$argPos] <$rsync_argv[$argPos]> Failure: this arg is not .\n");
   $ok = $FALSE;
 }
 
@@ -132,7 +135,7 @@ $argPos++;
 my $log_substr = substr ("$rsync_argv[$argPos]", 0, length($chrootDir));
 
 unless ($log_substr eq $chrootDir && ((index $rsync_argv[$argPos], '../') eq -1)) {
-  print SSHOUT ("ARG[5] <$rsync_argv[$argPos]> Failure\n");
+  print SSHOUT ("ARG[5] <$rsync_argv[$argPos]> Failure: this arg does not begin with $chrootDir\n");
   $ok = $FALSE;
 }
 
