@@ -4,8 +4,13 @@
 # Copyright (c)2004-2007 Yves Van den Hove (yves\@vandenhove.tk) & Alex Peeters (alex.peeters\@citap.com)
 #
 # ---------------------------------------------------------------------------------------------------------
+# 2007-03-16 - Version 1.19: Bugfix for posts with only one variable
+# 2007-03-14 - Version 1.18: Bugfix for basicAuthenticationUser & basicAuthenticationPassword
+# 2007-03-10 - Version 1.17: Bugfix for POST requests without arguments, code optimalisations
+# 2007-01-30 - Version 1.16: Bugfix for POST requests with arguments, code optimalisations
+# 2007-01-25 - Version 1.15: Added basicAuthenticationUser & basicAuthenticationPassword
 # 2006-12-05 - Version 1.14: No more .bmp
-# 2006-11-27 - Version 1.13: Support for robots.txt and automatic numbering for Perfdata_Label
+# 2006-11-27 - Version 1.13: Support for robots.txt, automatic numbering for Perfdata_Label
 # 2006-03-10 - Version 1.12: "POST" --> 'POST', "GET" --> 'GET', bug fixed for missing 0 in values
 # 2006-02-22 - Version 1.11: " --> '
 # 2006-02-21 - Version 1.10: Variables are now quoted, little optimalisations
@@ -21,8 +26,6 @@
 # 2004-06-11 - Version 1.1:  List output format
 # 2004-06-09 - Version 1.0:  Original design
 # ---------------------------------------------------------------------------------------------------------
-# Last Update: 05/12/2006 16:13
-# ---------------------------------------------------------------------------------------------------------
 
 use strict;
 use warnings;
@@ -31,7 +34,7 @@ use vars qw($opt_i $opt_o $opt_f $opt_h $opt_v $PROGNAME);
 
 my $PROGNAME = "GrinderCaptureConverter.pl";
 my $prgtext  = "Grinder Capture Converter";
-my $version  = "1.14";
+my $version  = "1.19";
 my $debug    = 0;
 
 my $infile;
@@ -40,6 +43,7 @@ my $format;
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
+sub build_QS_fixed($);
 sub output_webtransact();
 sub output_list();
 sub print_help();
@@ -61,7 +65,7 @@ GetOptions (
 if ($opt_v) { print_revision(); exit(0); }
 if ($opt_h) { print_help();     exit(0); }
 
-if ($opt_i) { $infile  = $opt_i; } else { print_revision(); print_usage(); print("$PROGNAME: No grinder input file specified!\n\n");  exit(0); }
+if ($opt_i) { $infile  = $opt_i; } else { print_revision(); print_usage(); print("$PROGNAME: No grinder input file specified!\n\n"); exit(0); }
 if ($opt_o) { $outfile = $opt_o; } else { print_revision(); print_usage(); print("$PROGNAME: No output file specified!\n\n"); exit(0); }
 if ($opt_f) { if ($opt_f eq "L" or $opt_f eq "W") { $format = $opt_f; } else { print_revision(); print_usage(); print("$PROGNAME: Wrong format specified!\n\n"); exit(0); } } else { $format = "W"; }
 
@@ -85,6 +89,8 @@ my @urlArray;
 my @postArray;
 my @dataArray;
 my $url;
+my $user;
+my $password;
 my $postType;
 my $postData;
 my $written = 1;
@@ -93,96 +99,92 @@ my $written = 1;
 foreach my $l (@inArray){
   $l =~ s/\r//g;
   $l =~ s/\n//g;
+
   if ($l =~ /.parameter.url=/) {
     # De vorige url pushen
     if (! $written) {
-      push (@postArray, "$postType");
-      push (@urlArray,  "$url");
-      push (@dataArray, "$postData");
+      $url =~ s|^(http[s]*://)|$1$user\:$password\@| if(defined $user && defined $password);
+      push (@postArray, $postType);
+      push (@urlArray, $url);
+      push (@dataArray, $postData);
+      $user = undef;
+      $password = undef;
       $written = 1;
     }
 
     # De nieuwe url bepalen
     my $pos = index($l, "=") + 1;
     $url = substr($l, $pos);
-    $postType = "GET ";
-    $postData = "<NIHIL>";
-    $written = 0;
+    $postType = 'GET';
+    $postData = '<NIHIL>';
+    $written  = 0;
   } elsif ($l =~ /.parameter.header.If-Modified-Since=/) {
-    $postType = "GET ";
-    $written = 0;
+    $postType = 'GET';
+    $written  = 0;
   } elsif ($l =~ /.parameter.header.Content-Type=/) {
-    $postType = "POST";
-    $written = 0;
+    $postType = 'POST';
+    $written  = 0;
   } elsif ($l =~ /.parameter.post=/) {
     my $pos = index($l, "=") + 1;
     open (POSTFILE, $directory . substr($l, $pos)) || die ("Could not open post file");
     $postData = <POSTFILE>;
     close (POSTFILE);
+  } elsif ($l =~ /.basicAuthenticationUser=/) {
+    my $pos = index($l, "=") + 1;
+    $user = substr($l, $pos);
+    $written = 0;
+  } elsif ($l =~ /.basicAuthenticationPassword=/) {
+    my $pos = index($l, "=") + 1;
+    $password = substr($l, $pos);
+    $written = 0;
   }
 }
 
 if (! $written) {
-   #chop($url);
-   push (@urlArray,  "$url");
-   push (@postArray, "$postType");
-   push (@dataArray, "$postData");
+  $url =~ s|^(http[s]*://)|$1$user\:$password\@| if(defined $user && defined $password);
+  push (@urlArray, $url);
+  push (@postArray, $postType);
+  push (@dataArray, $postData);
+  $user = undef;
+  $password = undef;
+  $written = 1;   
 }
 
 if ($format eq "W") {
-   output_webtransact ();
+  output_webtransact();
 } else {
-   output_list ();
+  output_list();
 }
 
 exit(0);
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-sub output_webtransact () {
+sub output_webtransact() {
   open (OUTFILE, ">$outfile") || die ("Could not open webtransact output file");
   print OUTFILE "\@URLS = (\n";
 
-  for(my $c = 0, my $t = 1; $c < @urlArray; $c++) 
-  {
-    if (! ($urlArray[$c] =~ /(\.(gif|jpg|png|css|ico|js|bmp)|(robots\.txt))$/i) ) 
-	{
-      if($postArray[$c] eq "POST") 
-	  {
-         my @tArray1 = split(/&/, $dataArray[$c]);
-		 my(undef, $tFilename) = $urlArray[$c] =~ m/(.*\/)(.*)$/;
-         my $Qs_fixed;
-         foreach my $line (@tArray1)
-		 {
-         	my ($name, $value) = split(/=/, $line);
-         	if (! defined $value) { $value = ""; }
-         	$Qs_fixed .= "'" . URLDecode($name) . "'" . " => " . "'" . URLDecode($value) . "'" . ", ";
-         }  
-	     $Qs_fixed = substr($Qs_fixed, 0, -2);
-         print OUTFILE "  { Method => 'POST', Url => \"" . URLDecode($urlArray[$c]) . "\", Qs_var => [], Qs_fixed => [$Qs_fixed], Exp => '<NIHIL>', Exp_Fault => EXP_FAULT, Msg => '$tFilename', Msg_Fault => MSG_FAULT, Perfdata_Label => '[". sprintf("%02d", $t++) ."] $tFilename' },\n";
-      } 
-	  else 
-	  {
-      	 my ($tUrl, $tParams)  = split(/\?/, $urlArray[$c]);
-      	 my(undef, $tFilename) = $tUrl =~ m/(.*\/)(.*)$/; 	
-      	 my @tArray1 = split(/&/, $tParams) if (defined $tParams && $tParams ne '');
-         my $Qs_fixed;
-         if(@tArray1) 
-		 {
-	        foreach my $line (@tArray1)
-			{
-	       	   my ($name, $value) = split(/=/, $line);
-	           if (! defined $value) { $value = ""; }
-	           $Qs_fixed .= "'" . URLDecode($name) . "'" . " => " . "'" . URLDecode($value) . "'" . ", ";
-	        }          	
-		 } 
-		 else 
-		 {
-	    	$Qs_fixed="";
-		 }
-	     $Qs_fixed = substr($Qs_fixed, 0, -2);
-         print OUTFILE "  { Method => 'GET',  Url => \"" . URLDecode($tUrl) . "\", Qs_var => [], Qs_fixed => [$Qs_fixed], Exp => '<NIHIL>', Exp_Fault => EXP_FAULT, Msg => '$tFilename', Msg_Fault => MSG_FAULT, Perfdata_Label => '[". sprintf("%02d", $t++) ."] $tFilename' },\n";
+  for(my $c = 0, my $t = 1; $c < @urlArray; $c++) {
+    if (! ($urlArray[$c] =~ /(\.(gif|jpg|png|css|ico|js|bmp)|(robots\.txt))$/i) ) {
+	  my($tUrl, $tParams)   = split(/\?/, $urlArray[$c]);  
+	  my(undef, $tFilename) = $tUrl =~ m/(.*\/)(.*)$/;
+      my $Qs_fixed = '';
+
+      if (defined $tParams && $tParams ne '') {
+        my @tArray = split(/&/, $tParams);
+        $Qs_fixed .= build_QS_fixed(\@tArray);
       }
+		 
+      if($postArray[$c] eq 'POST') {
+        $Qs_fixed .= ", " if($Qs_fixed ne ''); 
+
+        if ( defined $dataArray[$c] and  $dataArray[$c] ne '') {
+		  my @tArray = split(/&/, $dataArray[$c]);
+          $Qs_fixed .= build_QS_fixed(\@tArray);
+        }
+      }
+		 
+      print OUTFILE "  { Method => '" . $postArray[$c] . "', Url => \"" . URLDecode(PERLDecode($tUrl)) . "\", Qs_var => [], Qs_fixed => [$Qs_fixed], Exp => '<NIHIL>', Exp_Fault => EXP_FAULT, Msg => '$tFilename', Msg_Fault => MSG_FAULT, Perfdata_Label => '[". sprintf("%02d", $t++) ."] $tFilename' },\n";
     }
   }
 
@@ -192,6 +194,26 @@ sub output_webtransact () {
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
+sub build_QS_fixed($) {
+  my $tArray   = shift;
+
+  my $Qs_fixed = '';
+
+  if ( defined @$tArray ) {
+	foreach my $line (@$tArray) {
+	  my ($name, $value) = split(/=/, $line);
+
+      if (! defined $value) { $value = ""; }
+      $Qs_fixed .= ", " if($Qs_fixed ne '');
+      $Qs_fixed .= "'" . URLDecode($name) . "'" . " => " . "'" . URLDecode($value) . "'";
+	}
+  }  
+
+  return $Qs_fixed;
+}
+  
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+  
 sub URLDecode {
     my $theURL = $_[0];
     $theURL =~ tr/+/ /;
@@ -202,15 +224,29 @@ sub URLDecode {
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-sub output_list () {
+sub PERLDecode {
+	my $theURL = $_[0];
+	$theURL =~ s|\@|\\@|g;
+	return $theURL;
+}
+
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+
+sub output_list() {
   open (OUTFILE, ">$outfile") || die ("Could not open list output file");
 
   for(my $c = 0; $c < @urlArray; $c++) {
     if (! ($urlArray[$c] =~ /(\.(gif|jpg|png|css|ico|js|bmp)|(robots\.txt))$/i) ) {
+	  my $tUrl = URLDecode($urlArray[$c]);
+
       if($postArray[$c] eq "POST") {
-        print OUTFILE "$postArray[$c]" . " - " . URLDecode($urlArray[$c]) . "?" . URLDecode($dataArray[$c]) . "\n";
+	  	if ( defined $dataArray[$c] and  $dataArray[$c] ne '') {
+	      print OUTFILE "$postArray[$c]" . " - " . $tUrl . ( ($tUrl =~ /\?/) ? '&' : '?' ) . URLDecode($dataArray[$c]) . "\n";
+		} else {
+		  print OUTFILE "$postArray[$c]" . " - " . $tUrl . "\n";
+		}
       } else {
-        print OUTFILE "$postArray[$c]" . " - " . URLDecode($urlArray[$c]) . "\n";
+        print OUTFILE "$postArray[$c]" . "  - " . $tUrl . "\n";
       }
     }
   }
@@ -236,7 +272,7 @@ sub print_revision() {
 sub print_help() {
   print_revision();
   print_usage();
-  print "Send an email to yves\@vandenhove.tk if you have any questions regarding the use of this software.\n";
+  print "Send an email to yves.vandenhove\@smals-mvm.be if you have any questions regarding the use of this software.\n";
 }
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
